# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import int_connector_lib.proto.grpc_stdio_pb2 as grpc__stdio__pb2


class GRPCStdioStub(object):
    """GRPCStdio is a service that is automatically run by the plugin process
    to stream any stdout/err data so that it can be mirrored on the plugin
    host side.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StreamStdio = channel.unary_stream(
            "/plugin.GRPCStdio/StreamStdio",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=grpc__stdio__pb2.StdioData.FromString,
        )


class GRPCStdioServicer(object):
    """GRPCStdio is a service that is automatically run by the plugin process
    to stream any stdout/err data so that it can be mirrored on the plugin
    host side.
    """

    def StreamStdio(self, request, context):
        """StreamStdio returns a stream that contains all the stdout/stderr.
        This RPC endpoint must only be called ONCE. Once stdio data is consumed
        it is not sent again.

        Callers should connect early to prevent blocking on the plugin process.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_GRPCStdioServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StreamStdio": grpc.unary_stream_rpc_method_handler(
            servicer.StreamStdio,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=grpc__stdio__pb2.StdioData.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("plugin.GRPCStdio", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class GRPCStdio(object):
    """GRPCStdio is a service that is automatically run by the plugin process
    to stream any stdout/err data so that it can be mirrored on the plugin
    host side.
    """

    @staticmethod
    def StreamStdio(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/plugin.GRPCStdio/StreamStdio",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            grpc__stdio__pb2.StdioData.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



import logging
import time
import typing

import grpc

from int_connector_lib.proto import (
    grpc_broker_pb2,
    grpc_broker_pb2_grpc,
)

P = typing.ParamSpec("P")

TYPE = "dummy connector"
VERSION = "v0.0.1"


class Broker(grpc_broker_pb2_grpc.GRPCBroker):
    """Implement grpc Broker for bidirectional communication."""

    def __init__(self: typing.Self, logger: logging.Logger) -> None:
        self.logger = logger
        self._streams = {}

    @property
    def streams(self: typing.Self) -> dict:
        """Return internal stream store."""
        return self._streams

    def StartStream(
        self: typing.Self,
        request: grpc_broker_pb2.ConnInfo,  # RequestIterator
        context: grpc.ServicerContext,
    ) -> grpc_broker_pb2.ConnInfo:  # ResponseIterator
        """Handle rpc.StartStream call."""
        self.logger.debug("Start Stream")
        for r in request:
            self.logger.debug(r)
            self.streams[r.service_id] = r
            # TODO(edgy): Return accurate conn info, bidirectional seems to work regardess
            yield grpc_broker_pb2.ConnInfo()

    def Dial(self: typing.Self, service_id: int) -> grpc.Channel:
        """Implement Broker.Dial.

        Given a service_id, generate a grpc.Channel for the associated service.
        """
        while service_id not in self.streams:
            self.logger.debug("Waiting for stream %s.", service_id)
            time.sleep(0.1)
        self.logger.debug("Dialing %s", service_id)
        self.logger.debug(self.streams)
        conn_info = self.streams[service_id]
        self.logger.info("Dialing %s:%s", conn_info.network, conn_info.address)
        return grpc.insecure_channel(f"{conn_info.network}://{conn_info.address}")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: manager.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\rmanager.proto\x12\x05proto\x1a\x1bgoogle/protobuf/empty.proto"J\n\x0fSendDataRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1d\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\r.proto.Format\x12\x0c\n\x04\x64\x61ta\x18\n \x01(\x0c"f\n\x0fSendFileRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1d\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\r.proto.Format\x12\x0c\n\x04path\x18\n \x01(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"O\n\x15SendJSONSchemaRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"7\n\x18SendColumnsSchemaRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t"t\n\x1aReportDataUnitStateRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0f\n\x07healthy\x18\x04 \x01(\x08\x12\x11\n\x04name\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name*T\n\x06\x46ormat\x12\x12\n\x0e\x46ORMAT_UNKNOWN\x10\x00\x12\x0f\n\x0b\x46ORMAT_JSON\x10\x01\x12\x11\n\rFORMAT_STRING\x10\x02\x12\x12\n\x0e\x46ORMAT_PARQUET\x10\x03\x32\xe9\x02\n\x07Manager\x12:\n\x08SendData\x12\x16.proto.SendDataRequest\x1a\x16.google.protobuf.Empty\x12:\n\x08SendFile\x12\x16.proto.SendFileRequest\x1a\x16.google.protobuf.Empty\x12\x46\n\x0eSendJSONSchema\x12\x1c.proto.SendJSONSchemaRequest\x1a\x16.google.protobuf.Empty\x12L\n\x11SendColumnsSchema\x12\x1f.proto.SendColumnsSchemaRequest\x1a\x16.google.protobuf.Empty\x12P\n\x13ReportDataUnitState\x12!.proto.ReportDataUnitStateRequest\x1a\x16.google.protobuf.EmptyB\tZ\x07.;protob\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "manager_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\007.;proto"
    _globals["_FORMAT"]._serialized_start = 489
    _globals["_FORMAT"]._serialized_end = 573
    _globals["_SENDDATAREQUEST"]._serialized_start = 53
    _globals["_SENDDATAREQUEST"]._serialized_end = 127
    _globals["_SENDFILEREQUEST"]._serialized_start = 129
    _globals["_SENDFILEREQUEST"]._serialized_end = 231
    _globals["_SENDJSONSCHEMAREQUEST"]._serialized_start = 233
    _globals["_SENDJSONSCHEMAREQUEST"]._serialized_end = 312
    _globals["_SENDCOLUMNSSCHEMAREQUEST"]._serialized_start = 314
    _globals["_SENDCOLUMNSSCHEMAREQUEST"]._serialized_end = 369
    _globals["_REPORTDATAUNITSTATEREQUEST"]._serialized_start = 371
    _globals["_REPORTDATAUNITSTATEREQUEST"]._serialized_end = 487
    _globals["_MANAGER"]._serialized_start = 576
    _globals["_MANAGER"]._serialized_end = 937
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: source.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0csource.proto\x12\x05proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto"L\n\x0cStartRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12"\n\x07sources\x18\x02 \x03(\x0b\x32\x11.proto.DataSource\x12\x0c\n\x04name\x18\n \x01(\t"]\n\nDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\'\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\x04name\x18\n \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"9\n\x0bStopRequest\x12*\n\x07Timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration".\n\rStatusMessage\x12\x1d\n\x06status\x18\x01 \x01(\x0e\x32\r.proto.Status"W\n\x0e\x44\x65tailsMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x11\n\x04name\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name"G\n\x0b\x44\x61taMessage\x12\x0f\n\x07manager\x18\x01 \x01(\r\x12\'\n\x06source\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct".\n\x03Run\x12\'\n\x06source\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"Y\n\rConfigMessage\x12(\n\rSourcesConfig\x18\x01 \x03(\x0b\x32\x11.proto.DataSource\x12\x1e\n\nRunsConfig\x18\x02 \x03(\x0b\x32\n.proto.Run"J\n\x11ValidationMessage\x12\r\n\x05valid\x18\x01 \x01(\x08\x12&\n\x06\x65rrors\x18\x02 \x03(\x0b\x32\x16.proto.ValidationError"4\n\x0fValidationError\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t""\n\x14StartedStreamMessage\x12\n\n\x02ID\x18\x01 \x01(\t"\x1f\n\x11StopStreamMessage\x12\n\n\x02ID\x18\x01 \x01(\t*T\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x12\n\x0eSTATUS_RUNNING\x10\x02\x12\x10\n\x0cSTATUS_ERROR\x10\x03\x32\xad\x02\n\nBaseSource\x12\x34\n\x05Start\x12\x13.proto.StartRequest\x1a\x16.google.protobuf.Empty\x12\x32\n\x04Stop\x12\x12.proto.StopRequest\x1a\x16.google.protobuf.Empty\x12\x39\n\tGetStatus\x12\x16.google.protobuf.Empty\x1a\x14.proto.StatusMessage\x12;\n\nGetDetails\x12\x16.google.protobuf.Empty\x1a\x15.proto.DetailsMessage\x12=\n\x0b\x43heckConfig\x12\x14.proto.ConfigMessage\x1a\x18.proto.ValidationMessage2?\n\x06Source\x12\x35\n\x07GetData\x12\x12.proto.DataMessage\x1a\x16.google.protobuf.Empty2\x91\x01\n\x0fStreamingSource\x12>\n\x0bStartStream\x12\x12.proto.DataMessage\x1a\x1b.proto.StartedStreamMessage\x12>\n\nStopStream\x12\x18.proto.StopStreamMessage\x1a\x16.google.protobuf.EmptyB\tZ\x07.;protob\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "source_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\007.;proto"
    _globals["_STATUS"]._serialized_start = 894
    _globals["_STATUS"]._serialized_end = 978
    _globals["_STARTREQUEST"]._serialized_start = 114
    _globals["_STARTREQUEST"]._serialized_end = 190
    _globals["_DATASOURCE"]._serialized_start = 192
    _globals["_DATASOURCE"]._serialized_end = 285
    _globals["_STOPREQUEST"]._serialized_start = 287
    _globals["_STOPREQUEST"]._serialized_end = 344
    _globals["_STATUSMESSAGE"]._serialized_start = 346
    _globals["_STATUSMESSAGE"]._serialized_end = 392
    _globals["_DETAILSMESSAGE"]._serialized_start = 394
    _globals["_DETAILSMESSAGE"]._serialized_end = 481
    _globals["_DATAMESSAGE"]._serialized_start = 483
    _globals["_DATAMESSAGE"]._serialized_end = 554
    _globals["_RUN"]._serialized_start = 556
    _globals["_RUN"]._serialized_end = 602
    _globals["_CONFIGMESSAGE"]._serialized_start = 604
    _globals["_CONFIGMESSAGE"]._serialized_end = 693
    _globals["_VALIDATIONMESSAGE"]._serialized_start = 695
    _globals["_VALIDATIONMESSAGE"]._serialized_end = 769
    _globals["_VALIDATIONERROR"]._serialized_start = 771
    _globals["_VALIDATIONERROR"]._serialized_end = 823
    _globals["_STARTEDSTREAMMESSAGE"]._serialized_start = 825
    _globals["_STARTEDSTREAMMESSAGE"]._serialized_end = 859
    _globals["_STOPSTREAMMESSAGE"]._serialized_start = 861
    _globals["_STOPSTREAMMESSAGE"]._serialized_end = 892
    _globals["_BASESOURCE"]._serialized_start = 981
    _globals["_BASESOURCE"]._serialized_end = 1282
    _globals["_SOURCE"]._serialized_start = 1284
    _globals["_SOURCE"]._serialized_end = 1347
    _globals["_STREAMINGSOURCE"]._serialized_start = 1350
    _globals["_STREAMINGSOURCE"]._serialized_end = 1495
# @@protoc_insertion_point(module_scope)



import typing

import pydantic
from google.protobuf.struct_pb2 import Struct

T = typing.TypeVar("T", bound=pydantic.BaseModel)


class PluginConfig(pydantic.BaseModel):
    """Base config model to handle grpc config structs."""

    @classmethod
    def from_struct(cls: type[T], struct: Struct) -> T:
        """Convert google protobuf.Struct to a config object."""
        data = dict(struct.items())
        return cls(**data)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc_broker.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x11grpc_broker.proto\x12\x06plugin"\x9b\x01\n\x08\x43onnInfo\x12\x12\n\nservice_id\x18\x01 \x01(\r\x12\x0f\n\x07network\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12%\n\x05knock\x18\x04 \x01(\x0b\x32\x16.plugin.ConnInfo.Knock\x1a\x32\n\x05Knock\x12\r\n\x05knock\x18\x01 \x01(\x08\x12\x0b\n\x03\x61\x63k\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\t2C\n\nGRPCBroker\x12\x35\n\x0bStartStream\x12\x10.plugin.ConnInfo\x1a\x10.plugin.ConnInfo(\x01\x30\x01\x42\nZ\x08./pluginb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "grpc_broker_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\010./plugin"
    _globals["_CONNINFO"]._serialized_start = 30
    _globals["_CONNINFO"]._serialized_end = 185
    _globals["_CONNINFO_KNOCK"]._serialized_start = 135
    _globals["_CONNINFO_KNOCK"]._serialized_end = 185
    _globals["_GRPCBROKER"]._serialized_start = 187
    _globals["_GRPCBROKER"]._serialized_end = 254
# @@protoc_insertion_point(module_scope)



import typing
from enum import Enum

import grpc

from int_connector_lib.proto import (
    manager_pb2,
    manager_pb2_grpc,
)
from int_connector_lib.protobuf import Empty


class DataFormat(Enum):  # noqa: D101
    FORMAT_UNKNOWN = manager_pb2.Format.FORMAT_UNKNOWN
    FORMAT_STRING = manager_pb2.Format.FORMAT_STRING
    FORMAT_JSON = manager_pb2.Format.FORMAT_JSON
    FORMAT_PARQUET = manager_pb2.Format.FORMAT_PARQUET


class Manager:
    """Wrapper for ManagerStub."""

    def __init__(self: typing.Self, channel: grpc.Channel) -> None:
        self.mgr = manager_pb2_grpc.ManagerStub(channel)

    def send_data(self: typing.Self, source_id: str, data_format: DataFormat, data: bytes) -> Empty:
        """Send data to manager."""
        self.mgr.SendData(
            manager_pb2.SendDataRequest(
                id=source_id,
                format=data_format.value,
                data=data,
            ),
        )
